@@ -151,7 +151,7 @@ class AbstractNear2FarData(MonitorData):
             theta and phi coordinates relative to ``local_origin``.
         """
         phi_local = np.arctan2(uy, ux)
-        theta_local = np.arctan(np.sqrt(ux**2 + uy**2))
+        theta_local = np.arcsin(np.sqrt(ux**2 + uy**2))
         # Spherical coordinates rotation matrix reference:
         # https://en.wikipedia.org/wiki/Rodrigues%27_rotation_formula#Matrix_notation
         if axis == 0:
